---
'gatsby-plugin-twind': patch
'@twind/with-sveltekit': patch
'@twind/tailwind': patch
'twind': patch
---

server side generated styles are resumed in the browser

Server side generated styles now include resume data that allows twind in the browser to know which styles are already included in the stylesheet. This change significantly reduces the time to interactive, supports hashed classes, and prevents missing classes that have been generated by `css` or `style` and are not yet registered.

Resuming styles is enabled by default for `setup` (_Shim Mode_).

```js
import { setup } from 'twind'
import config from './twind.config'

// styles are resumed!
setup(config)
```

If you want to used the `dom` sheet during development or if you currently pass a sheet as the second argument, please switch to the new `getSheet(useDOMSheet?: boolean, disableResume?: boolean)` function. This function returns a `Sheet` for the current environment — `virtual` on server, either `dom` or `cssom` in browsers.

```js
import { setup, getSheet } from 'twind'
import config from './twind.config'

setup(config, getSheet(process.env.NODE_ENV != 'production'))
```

If you want to use resuming styles with _Library Mode_ you need to adjust your code to use `getSheet`:

```js
import { twind, getSheet } from 'twind'
import config from './twind.config'

export const tw = twind(config, getSheet(process.env.NODE_ENV != 'production'))
```

To generate server side styles use either `inline` or `extract`:

```js
import { inline, extract } from 'twind'

// 1. using inline
const html = inline(renderApp())

// 2. using extract
const { html, css } = extract(renderApp())
// add the css to the head using <style data-twind>{css}</style>
```

The signature of `virtual(includeResumeData?: boolean)` has changed as well. This is technically a breaking change, but I doubt anybody has used the previous possible `virtual([])`.
